@@ -1,9 +1,28 @@
 ####################################################################################
 ####################################################################################
 ####################################################################################
-# this function is needed in ALE but it should be use to all partial effect functions
-###################################################################################
-####################################################################################
+# this function is needed in ALE but it should be possibly use to all partial effect
+#  functions 
+#  for any use with pe_ we need to be able to create the list with all formulea from 
+#  parameters
+getAll.formulae2data <- function(obj, data)
+{
+  if (!is(obj,"gamlss")) stop("it needs a gamlss object")
+  param <- obj$parameters
+  lparam <- length(param)
+  formul <- list()
+  for (i in 1:lparam) 
+  {
+    # browser()
+    #                           obj[[paste0(param[i],".formula")]][[3]][1:2]
+    formul[[param[i]]] <- as.formula(obj[[paste0(param[i],".formula")]])
+  }
+  DaTa <-  Formulae2data(formul, data=data) #
+  DaTa
+}
+################################################################################
+################################################################################
+################################################################################
 Formulae2data <- function(formula = list(), data=NULL, weights=NULL, subset=NULL, 
                           na.action, print = TRUE  )
 {
@@ -19,12 +38,13 @@ Formulae2data <- function(formula = list(), data=NULL, weights=NULL, subset=NULL
       # the first formula  
       form <- formula(formula[[1]])
       # create y~x+   
-      f1 <- paste(paste(form[[2]],form[[1]]), deparse(form[[3]]), "+")
+      f1 <- ff <- paste(paste(form[[2]],form[[1]]), deparse(form[[3]]), "+")
       # now add the of he formulae    
       for (i in 2:lenList)
       {
-        ff <- if (i==lenList) paste(f1, deparse(formula[[i]][[2]]))
-        else paste(f1, deparse(formula[[i]][[2]]),"+")
+        ff <- if (i==lenList) paste(ff, deparse(formula[[i]][[2]]))
+        else paste(ff, deparse(formula[[i]][[2]]),"+")
+        
       } 
     }
   } else if (is(formula,"formula")) {ff  <- deparse(substitute(formula))}
@@ -37,7 +57,7 @@ Formulae2data <- function(formula = list(), data=NULL, weights=NULL, subset=NULL
   }
   environment(ff) <- globalenv()    # do I need this
   all.vars <- get_all_vars(ff, data=data)
-  if (!is.null(data)&&!inherits(data, "data.frame")) warning("data is not a data frame class attributes will be lost")
+  if (!is.null(data)&&!inherits(data,"data.frame")) warning("data is not a data frame class attributes will be lost")
   M <- dim(all.vars)[1]
   ## subsetting             
   if (!is.null(subset)) {
@@ -56,8 +76,7 @@ Formulae2data <- function(formula = list(), data=NULL, weights=NULL, subset=NULL
   if (print) cat( N, "observations with", dim(all.vars)[2], "variables \n")    
   attr(all.vars, "formula") <- ff
   all.vars
-}     
-####################################################################################
-####################################################################################
-####################################################################################      
-
+}
+################################################################################
+################################################################################
+################################################################################
\ No newline at end of file
