@@ -57,15 +57,17 @@ gamlssNews <- function() file.show(system.file("doc", "NEWS.txt", package="gamls
                    "la", "plag",                  # time series penalised lags, 
                    "tr",                          # decision trees  
                    "ga", "ba", "mm",              # gam - bam Simon Wood      
-                   "nn",                          # neural netwoks           : nn
-                   "sv",                          # suppor vector machines   : sv 
-                   "ma",                          # mars                     : ma
-                   "pcr",                         # principal component Reg  : pcr
-				           "pc",                          # principal component regr : pc
+                   "nn",                          # neural netwoks           
+                   "sv",                          # suppor vector machines   
+                   "ma",                          # mars                     
+                   "pcr",                         # principal component Reg  
+				           "pc",                          # principal component regr 
 				           "h2o",                         # h2o project 
 				           "pa",                          # partial regression
-				           "gnet", "lrs")                 # glmnet and lars
-                   
+				           "gnet", "lrs",                 # glmnet and lars
+                   "rforest",                     # random forest
+				           "gboost",                      # generalised Tree boosting
+				           "gsel")                        # gamsel 
 # note that predict only read 2 characters Monday, May 4, 2009 at 11:27
 ##----------------------------------------------------------------------------------------
 # .gamlss.sm.list<-c( "ar", "arma",
