@@ -195,7 +195,7 @@ extractAIC.gamlss<-function (fit, scale, k = 2, c = FALSE,  ...)
 stepGAIC.VR <-function(object, 
                     scope, 
                 direction = c("both", "backward", "forward"), 
-                    trace = T, 
+                    trace = TRUE, 
                      keep = NULL, 
                     steps = 1000,
                     scale = 0,
@@ -425,7 +425,7 @@ stepGAIC.VR <-function(object,
 stepGAIC.CH <-function(object, 
                     scope = gamlss.scope(model.frame(object)), 
                 direction = c("both", "backward", "forward"), 
-                    trace = T, 
+                    trace = TRUE, 
                      keep = NULL, 
                     steps = 1000,
                      what = c("mu", "sigma", "nu", "tau"),
